@@ -157,12 +157,19 @@ class Directory:
     # the site catalog schema lists freeSize and totalSize as an attribute
     # however this appears to not be used; removing it as a parameter
     # def __init__(self, directory_type, path, free_size=None, total_size=None):
-    def __init__(self, directory_type: _DirectoryType, path: Union[str, Path]):
+    def __init__(
+        self,
+        directory_type: _DirectoryType,
+        path: Union[str, Path],
+        shared_file_system: bool = False,
+    ):
         """
         :param directory_type: directory type defined in :py:class:`~Pegasus.api.site_catalog.DirectoryType` (e.g. :code:`Directory.SHARED_SCRATCH` or :code:`Directory.LOCAL_STORAGE`)
         :type directory_type: _DirectoryType
         :param path: directory path
         :type path: Union[str, Path]
+        :param shared_file_system: indicate whether the shared scratch space is accessible to the worker nodes via a shared filesystem, defaults to False
+        :type shared_file_system: bool
         :raises ValueError: directory_type must be one of :py:class:`~Pegasus.api.site_catalog.DirectoryType`
         :raises ValueError: path must be given as an absolute path
         """
@@ -189,6 +196,8 @@ class Directory:
         # self.free_size = free_size
         # self.total_size = total_size
 
+        self.shared_file_system = shared_file_system
+
         self.file_servers = list()
 
     @_chained
@@ -216,6 +225,7 @@ class Directory:
             {
                 "type": self.directory_type,
                 "path": self.path,
+                "sharedFileSystem": self.shared_file_system,
                 "fileServers": [fs for fs in self.file_servers],
                 "freeSize": None,
                 "totalSize": None,
@@ -287,6 +297,7 @@ class Grid:
 
         self.scheduler_type = scheduler_type.value
 
+        self.job_type = job_type
         if job_type is not None:
             if not isinstance(job_type, SupportedJobs):
                 raise TypeError(
@@ -296,8 +307,6 @@ class Grid:
                 )
             else:
                 self.job_type = job_type.value
-        else:
-            self.job_type = None
 
     def __json__(self):
         return _filter_out_nones(
@@ -475,6 +484,8 @@ class SiteCatalog(Writable):
     _DEFAULT_FILENAME = "sites.yml"
 
     def __init__(self):
+        Writable.__init__(self)
+
         self.sites = dict()
 
     @_chained
