@@ -179,7 +179,7 @@ class TransformationSite(ProfileMixin, MetadataMixin):
         :type pfn: Union[str, Path]
         :param is_stageable: whether or not this transformation is stageable or installed, defaults to False
         :type type: bool, optional
-        :param bypass_staging: whether or not to bypass the stage in job of this executable (Note that this only works for transformations where :code:`is_stageable=False`), defaults to False
+        :param bypass_staging: whether or not to bypass the stage in job of this executable (Note that this only works for transformations where :code:`is_stageable=True`), defaults to False
         :type bypass_staging: bool, optional
         :param arch: architecture that this :py:class:`~Pegasus.api.transformation_catalog.Transformation` was compiled for (defined in :py:class:`~Pegasus.api.site_catalog.Arch`), defaults to None
         :type arch: Optional[Arch], optional
@@ -360,7 +360,7 @@ class Transformation(ProfileMixin, HookMixin, MetadataMixin):
         :type pfn: Optional[Union[str, Path]]
         :param is_stageable: whether or not this transformation is stageable or installed, defaults to False
         :type type: bool, optional
-        :param bypass_staging: whether or not to bypass the stage in job of this executable (Note that this only works for transformations where :code:`is_stageable=False`), defaults to False
+        :param bypass_staging: whether or not to bypass the stage in job of this executable (Note that this only works for transformations where :code:`is_stageable=True`), defaults to False
         :type bypass_staging: bool, optional
         :param arch: architecture that this transformation was compiled for (defined in :py:class:`~Pegasus.api.site_catalog.Arch` , e.g :code:`Arch.X86_64`), defaults to None
         :type arch: Optional[Arch]
@@ -626,6 +626,8 @@ class TransformationCatalog(Writable):
     _DEFAULT_FILENAME = "transformations.yml"
 
     def __init__(self):
+        Writable.__init__(self)
+
         self.transformations = dict()
         self.containers = dict()
 
